@@ -322,6 +322,7 @@ class Persona(Serializable, db.Model):
             p.crypt_public = changeset["crypt_public"]
             p.sign_public = changeset["sign_public"]
             p.modified = modified_dt
+            p._stub = False
         else:
             p = Persona(
                 id=changeset["id"],
@@ -1044,8 +1045,9 @@ class Starmap(Serializable, db.Model):
         """
         if Serializable.authorize(self, action, author_id=author_id):
             if self.kind == "persona_profile":
-                p = Persona.query.filter(Persona.profile_id == self.id)
-                return p.id == author_id
+                # p = Persona.query.filter(Persona.profile_id == self.id).first()
+                # return p.id == author_id
+                return self.author.id == author_id
             elif self.kind == "group_profile":
                 # Everyone can update
                 if action == "update":
